@@ -1866,6 +1866,52 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def QueryMetric(self, request):
+        """查询指定时刻指标的最新值
+
+        :param request: Request instance for QueryMetric.
+        :type request: :class:`tencentcloud.cls.v20201016.models.QueryMetricRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.QueryMetricResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryMetric", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryMetricResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def QueryRangeMetric(self, request):
+        """查询指定时间范围内指标的变化趋势
+
+        :param request: Request instance for QueryRangeMetric.
+        :type request: :class:`tencentcloud.cls.v20201016.models.QueryRangeMetricRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.QueryRangeMetricResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("QueryRangeMetric", params, headers=headers)
+            response = json.loads(body)
+            model = models.QueryRangeMetricResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def RetryShipperTask(self, request):
         """重试失败的投递任务
 
@@ -1889,6 +1935,29 @@ class ClsClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def SearchCosRechargeInfo(self, request):
+        """本接口用于预览cos导入信息
+
+        :param request: Request instance for SearchCosRechargeInfo.
+        :type request: :class:`tencentcloud.cls.v20201016.models.SearchCosRechargeInfoRequest`
+        :rtype: :class:`tencentcloud.cls.v20201016.models.SearchCosRechargeInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SearchCosRechargeInfo", params, headers=headers)
+            response = json.loads(body)
+            model = models.SearchCosRechargeInfoResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def SearchLog(self, request):
         """本接口用于检索分析日志, 该接口除受默认接口请求频率限制外，针对单个日志主题，查询并发数不能超过15。
 
